import { AxiosPromise } from "axios";
import axios from "./config";

// NOTE: 暂时使用ts-ignore忽略module not exported的问题
// @ts-ignore
import {
  IUser,
  IList,
  IDeliveryBook,
  IOfficialSimple,
  IBookSearchResult,
  ADpushSimple,
  IOfficials,
  ADPlanItem,
  deliveryPlanItem,
  IPlatform,
  adPlanLog
} from "@/types/api";

/**
 * 登录
 * @param userData 用户信息
 */
export const doLogin = <T>(userData: T): AxiosPromise<IUser> => {
  return axios.post("/login", userData);
};

/**
 * 书籍搜素
 * @param key_word
 * @param page
 */
export const getDeliveryBookList = (
  query: Partial<{
    official_name: string;
    book_name: string;
    page: number;
  }>   = { page: 1 }
): AxiosPromise<IList<IDeliveryBook>> => {
  return axios("/getUserDeliveryBooks", {
    params: query,
  });
};

/**
 * 获取公众号 - 无分页 用作于下拉
 */
export const getOfficialSimpleAccount = (): AxiosPromise<IOfficialSimple[]> => {
  return axios("/simpleUserOfficialAccounts");
};

/**
 * 通过书名搜索书籍
 * @param key_word
 * @param page
 */
export const getBooksByName = (
  key_word: string,
  page = 1
): AxiosPromise<IList<IBookSearchResult>> => {
  return axios("/searchBooks", { params: { key_word, page } });
};

/**
 * @description: 获取广告投放列表
 */
export const getAdPushList = (
  query: Partial<{
    email: string;
    account_name: string;
    account_id: string;
    page: number;
  }> = { page: 1 }
): AxiosPromise<IList<ADpushSimple>> => {
  return axios("/ad/accounts", { params: query });
};

/**
 * 获取公众号列表
 * @param query
 */
export const getOfficialAccounts = (query: {
  official_name: string;
  platform: string;
  page: number;
}): AxiosPromise<IList<IOfficials>> => {
  return axios("/userOfficialAccounts", { params: query });
};

/**
 * 获取公众号列表
 * @param query
 */
export const getADPlanlist = (
  query: Partial<{
    email: string;
    account_name: string;
    ad_name: string;
    status: string;
    begin_date: any;
    end_date: any;
    campaign_name: string;
    page: number;
  }> = { page: 1,status:'AD_STATUS_DELIVERY_OK' }
): AxiosPromise<IList<ADPlanItem>> => {
  return axios("/ad/adData", { params: query });
};

/**
 * @description: 获取投放数据列表
 */
export const getDeliveryStatList = (
  query: Partial<{
    start_time: string;
    end_time: string;
    official_name: string;
    book_name: string;
    page: number;
  }> = { page: 1 }
): AxiosPromise<any> => {
  return axios("/delivery/stat", { params: query });
};

/*
 * 获取平台列表
 */
export const getPlatforms = (): AxiosPromise<IPlatform[]> => {
  return axios("/simplePlatforms");
};

/**
 * 添加投放书籍
 * @param data
 */
export const addDeliveryBook = (data: {
  delivery_bid: string | number;
  official_id: string | number;
  platform: string;
}) => {
  return axios.post("/addDeliveryBook", data);
};

/**
 * 退出登录
 */
export const logout = () => {
  return axios("/logout");
};

/**
 * 停止投放书籍
 * @param id 记录id
 */
export const onStopDeliveryBook = (id: number) => {
  return axios("/stopDeliveryBook", { params: { id } });
};

/**
 * 自定义列
 * @param null
 */
export const getCustomColumn = () => {
  return axios("/ad/adFields");
};

/**
 * @description: 获取更多投放数据
 */
export const getDeliveryMoreStatList = (
  query: Partial<{
    start_time: string;
    end_time: string;
    official_name: string;
    book_name: string;
    page: number;
  }> = { page: 1 }
): AxiosPromise<IList<any>> => {
  return axios("/delivery/moreStat", { params: query });
};

/* 广告授权
 * @param null
 */
export const getAdauth = () => {
  return axios("/oauth/accountGrant");
};

/* 广告预算修改
 * @param null
 */
export const adChangeMoney = (data: {
  ad_id: string | number;
  budget: string | number;
}) => {
  return axios.post("/ad/updateAdBudget", data);
};

/* 广告出价修改
 * @param null
 */
export const adChangeCrem = (data: {
  ad_id: string | number;
  bid: string | number;
}) => {
  return axios.post("/api/updateAdBid", data);
};


/* 修改广告状态
 * @param null
 */
export const statusChange = (data: {
  ad_id: string | number;
  status: string;
}) => {
  return axios.post("/ad/updateAdStatus", data);
};

/* 获取操作日志
 * @param null
 */
export const opertaroLog = (
  query: Partial<{
    begin_time: string;
    end_time: string;
    page: number;
  }> = { page: 1 }
): AxiosPromise<IList<adPlanLog>> => {
  return axios("/ad/adOptLogs", { params: query });
};

/* 获取广告状态
 * @param null
 */
export const getAddStatus = (): AxiosPromise<any> => {
  return axios("/ad/adStatus");
};